@@ -1,4 +1,4 @@
-".First.lib" <-function(lib, pkg)
+".onLoad" <-function(lib, pkg)
 {
   library.dynam("bclust", package = pkg, lib.loc = lib)
   return(invisible(0)) 
